@@ -1,15 +1,15 @@
 import sys
 
 __title__ = 'xerox'
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 __author__ = 'Kenneth Reitz'
 __license__ = 'MIT'
 
 if sys.platform == 'darwin':
-    from darwin import *
+    from .darwin import *
     
 elif sys.platform == 'linux2':
-    from linux import *
+    from .linux import *
     
 elif sys.platform == 'win32':
-    from win import *
\ No newline at end of file
+    from .win import *
